@@ -30,277 +30,277 @@ void Kwave::FileInfo::PropertyTypesMap::fill()
 {
     append(Kwave::INF_UNKNOWN,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	QString(), QString());
+	QString(), KLazyLocalizedString());
 
     append(Kwave::INF_ALBUM,
 	FP_NONE,
-	_(I18N_NOOP("Album")),
-	_(I18N_NOOP("Name of the album if the source is an album\n"
-	    "that consist of more medias.")));
+	_(kli18n("Album").untranslatedText()),
+	kli18n("Name of the album if the source is an album\n"
+	    "that consist of more medias."));
     append(Kwave::INF_ANNOTATION,
 	FP_NONE,
-	_(I18N_NOOP("Annotation")),
-	_(I18N_NOOP(
+	_(kli18n("Annotation").untranslatedText()),
+	kli18n(
 	    "Provides general comments about the file or the subject of\n"
 	    "the file. If the comment is several sentences long, end\n"
 	    "each sentence with a period. Do not include newline\n"
-	    "characters!")));
+	    "characters!"));
     append(Kwave::INF_ARCHIVAL,
 	FP_NONE,
-	_(I18N_NOOP("Archival location")),
-	_(I18N_NOOP("Indicates where the subject of the file is archived.")));
+	_(kli18n("Archival location").untranslatedText()),
+	kli18n("Indicates where the subject of the file is archived."));
     append(Kwave::INF_AUTHOR,
 	FP_NONE,
-	_(I18N_NOOP("Author")),
-	_(I18N_NOOP("Identifies the name of the author of the original\n"
+	_(kli18n("Author").untranslatedText()),
+	kli18n("Identifies the name of the author of the original\n"
 	    "subject of the file."
-	    "\nExample: 'van Beethoven, Ludwig'")));
+	    "\nExample: 'van Beethoven, Ludwig'"));
     append(Kwave::INF_BITRATE_LOWER,
 	FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Lower Bitrate")),
-	_(I18N_NOOP("Specifies the lower limit in a VBR bitstream.")));
+	_(kli18n("Lower Bitrate").untranslatedText()),
+	kli18n("Specifies the lower limit in a VBR bitstream."));
     append(Kwave::INF_BITRATE_MODE,
 	FP_INTERNAL | FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Bitrate Mode")),
-	_(I18N_NOOP("Bitrate Mode (ABR, VBR, CBR, etc...)")));
+	_(kli18n("Bitrate Mode").untranslatedText()),
+	kli18n("Bitrate Mode (ABR, VBR, CBR, etc...)"));
     append(Kwave::INF_BITRATE_NOMINAL,
 	FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Bitrate")),
-	_(I18N_NOOP(
-	    "Nominal bitrate of the audio stream in bits per second")));
+	_(kli18n("Bitrate").untranslatedText()),
+	kli18n(
+	    "Nominal bitrate of the audio stream in bits per second"));
     append(Kwave::INF_BITRATE_UPPER,
 	FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Upper Bitrate")),
-	_(I18N_NOOP("Specifies the upper limit in a VBR bitstream.")));
+	_(kli18n("Upper Bitrate").untranslatedText()),
+	kli18n("Specifies the upper limit in a VBR bitstream."));
     append(Kwave::INF_BITS_PER_SAMPLE,
 	FP_INTERNAL | FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Bits per Sample")),
-	_(I18N_NOOP("Specifies the number of bits per sample.")));
+	_(kli18n("Bits per Sample").untranslatedText()),
+	kli18n("Specifies the number of bits per sample."));
     append(Kwave::INF_CD,
 	FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("CD")),
-	_(I18N_NOOP(
-	    "Number of the CD, if the source is an album of more CDROMs")));
+	_(kli18n("CD").untranslatedText()),
+	kli18n(
+	    "Number of the CD, if the source is an album of more CDROMs"));
     append(Kwave::INF_CDS,
 	FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("CDS")),
-	_(I18N_NOOP(
-	    "Number of CDs, if the source is an album of more CDROMs")));
+	_(kli18n("CDS").untranslatedText()),
+	kli18n(
+	    "Number of CDs, if the source is an album of more CDROMs"));
     append(Kwave::INF_COMMISSIONED,
 	FP_NONE,
-	_(I18N_NOOP("Commissioned")),
-	_(I18N_NOOP("Lists the name of the person or organization\n"
-	    "that commissioned the subject of the file.")));
+	_(kli18n("Commissioned").untranslatedText()),
+	kli18n("Lists the name of the person or organization\n"
+	    "that commissioned the subject of the file."));
     append(Kwave::INF_COMMENTS,
 	FP_NONE,
-	_(I18N_NOOP("Comments")),
-	_(I18N_NOOP(
+	_(kli18n("Comments").untranslatedText()),
+	kli18n(
 	    "Provides general comments about the file or the subject of\n"
 	    "the file. If the comment is several sentences long, end\n"
 	    "each sentence with a period. Do not include newline\n"
-	    "characters!")));
+	    "characters!"));
     append(Kwave::INF_COMPRESSION,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Compression")),
-	_(I18N_NOOP("Sets a mode for compressing the audio\n"
-	    "data to reduce disk space.")));
+	_(kli18n("Compression").untranslatedText()),
+	kli18n("Sets a mode for compressing the audio\n"
+	    "data to reduce disk space."));
     append(Kwave::INF_CONTACT,
 	FP_NONE,
-	_(I18N_NOOP("Contact")),
-	_(I18N_NOOP("Contact information for the creators or distributors of\n"
+	_(kli18n("Contact").untranslatedText()),
+	kli18n("Contact information for the creators or distributors of\n"
 	    "the track. This could be a URL, an email address, the\n"
-	    "physical address of the producing label.")));
+	    "physical address of the producing label."));
     append(Kwave::INF_COPYRIGHT,
 	FP_NONE,
-	_(I18N_NOOP("Copyright")),
-	_(I18N_NOOP("Records the copyright information for the file. "
+	_(kli18n("Copyright").untranslatedText()),
+	kli18n("Records the copyright information for the file. "
 	    "If there are\n"
 	    "multiple copyrights, separate them by a semicolon followed\n"
 	    "by a space.\n"
-	    "Example: 'Copyright Linux community 2002'")));
+	    "Example: 'Copyright Linux community 2002'"));
     append(Kwave::INF_COPYRIGHTED,
 	FP_NONE,
-	_(I18N_NOOP("Copyrighted")),
-	_(I18N_NOOP("Indicates whether the file is protected by "
-		"copyright or not.")));
+	_(kli18n("Copyrighted").untranslatedText()),
+	kli18n("Indicates whether the file is protected by "
+		"copyright or not."));
     append(Kwave::INF_CREATION_DATE,
 	FP_NONE,
-	_(I18N_NOOP("Date")),
-	_(I18N_NOOP("Specifies the date the subject of the file was created.\n"
-	    "Example: '2001-12-24'")));
+	_(kli18n("Date").untranslatedText()),
+	kli18n("Specifies the date the subject of the file was created.\n"
+	    "Example: '2001-12-24'"));
     append(Kwave::INF_ENGINEER,
 	FP_NONE,
-	_(I18N_NOOP("Engineer")),
-	_(I18N_NOOP("Shows the name of the engineer who worked on the file.\n"
+	_(kli18n("Engineer").untranslatedText()),
+	kli18n("Shows the name of the engineer who worked on the file.\n"
 	    "If there are multiple engineers, separate the names by\n"
-	    "a semicolon and a blank.")));
+	    "a semicolon and a blank."));
     append(Kwave::INF_ESTIMATED_LENGTH,
 	FP_INTERNAL | FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Estimated Length")),
-	_(I18N_NOOP("Estimated length of the file in samples")));
+	_(kli18n("Estimated Length").untranslatedText()),
+	kli18n("Estimated length of the file in samples"));
     append(Kwave::INF_FILENAME,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Filename")),
-	_(I18N_NOOP("Name of the opened file")));
+	_(kli18n("Filename").untranslatedText()),
+	kli18n("Name of the opened file"));
     append(Kwave::INF_FILESIZE,
 	FP_INTERNAL | FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("File Size")),
-	_(I18N_NOOP("Size of the file in bytes")));
+	_(kli18n("File Size").untranslatedText()),
+	kli18n("Size of the file in bytes"));
     append(Kwave::INF_GENRE,
 	FP_NONE,
-	_(I18N_NOOP("Genre")),
-	_(I18N_NOOP("Describes the genre or style of the original work.\n"
-	    "Examples: 'classic', 'pop'")));
+	_(kli18n("Genre").untranslatedText()),
+	kli18n("Describes the genre or style of the original work.\n"
+	    "Examples: 'classic', 'pop'"));
     append(Kwave::INF_ISRC,
 	FP_READONLY,
-	_(I18N_NOOP("ISRC")),
-	_(I18N_NOOP("ISRC number for the track; see the ISRC intro page\n"
+	_(kli18n("ISRC").untranslatedText()),
+	kli18n("ISRC number for the track; see the ISRC intro page\n"
 	    "for more information on ISRC numbers.\n"
-	    "http://www.ifpi.org/site-content/online/isrc_intro.html")));
+	    "http://www.ifpi.org/site-content/online/isrc_intro.html"));
     append(Kwave::INF_KEYWORDS,
 	FP_NONE,
-	_(I18N_NOOP("Keywords")),
-	_(I18N_NOOP("Provides a list of keywords that refer to the\n"
-	    "file or subject of the file.")));
+	_(kli18n("Keywords").untranslatedText()),
+	kli18n("Provides a list of keywords that refer to the\n"
+	    "file or subject of the file."));
     append(Kwave::INF_LABELS,
 	FP_INTERNAL,
-	_(I18N_NOOP("Labels")),
-	_(I18N_NOOP("The list of labels/markers.")));
+	_(kli18n("Labels").untranslatedText()),
+	kli18n("The list of labels/markers."));
     append(Kwave::INF_LENGTH,
 	FP_INTERNAL | FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Length")),
-	_(I18N_NOOP("Length of the file in samples.")));
+	_(kli18n("Length").untranslatedText()),
+	kli18n("Length of the file in samples."));
     append(Kwave::INF_LICENSE,
 	FP_NONE,
-	_(I18N_NOOP("License")),
-	_(I18N_NOOP("License information, e.g., 'All Rights Reserved',\n"
+	_(kli18n("License").untranslatedText()),
+	kli18n("License information, e.g., 'All Rights Reserved',\n"
 	    "'Any Use Permitted', an URL to a license or the\n"
 	    "EFF Open Audio License ('distributed under the\n"
 	    "terms of the Open Audio License.\n"
 	    "See http://www.eff.org/IP/Open_licenses/eff_oal.html\n"
-	    "for details'), etc.")));
+	    "for details'), etc."));
     append(Kwave::INF_MEDIUM,
 	FP_NONE,
-	_(I18N_NOOP("Medium")),
-	_(I18N_NOOP("Describes the original subject of the file,\n"
+	_(kli18n("Medium").untranslatedText()),
+	kli18n("Describes the original subject of the file,\n"
 	    "where it was first recorded.\n"
-	    "Example: 'orchestra'")));
+	    "Example: 'orchestra'"));
     append(Kwave::INF_MIMETYPE,
 	FP_READONLY | FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Mime Type")),
-	_(I18N_NOOP("Mime type of the file format")));
+	_(kli18n("Mime Type").untranslatedText()),
+	kli18n("Mime type of the file format"));
     append(Kwave::INF_MPEG_EMPHASIS,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Emphasis")),
-	_(I18N_NOOP("Audio emphasis mode")));
+	_(kli18n("Emphasis").untranslatedText()),
+	kli18n("Audio emphasis mode"));
     append(Kwave::INF_MPEG_LAYER,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Layer")),
-	_(I18N_NOOP("MPEG Layer, I, II or III")));
+	_(kli18n("Layer").untranslatedText()),
+	kli18n("MPEG Layer, I, II or III"));
     append(Kwave::INF_MPEG_MODEEXT,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Mode Extension")),
-	_(I18N_NOOP("MPEG Mode Extension (only if Joint Stereo)")));
+	_(kli18n("Mode Extension").untranslatedText()),
+	kli18n("MPEG Mode Extension (only if Joint Stereo)"));
     append(Kwave::INF_MPEG_VERSION,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Version")),
-	_(I18N_NOOP("MPEG Version, 1, 2 or 2.5")));
+	_(kli18n("Version").untranslatedText()),
+	kli18n("MPEG Version, 1, 2 or 2.5"));
     append(Kwave::INF_NAME,
 	FP_NONE,
-	_(I18N_NOOP("Name")),
-	_(I18N_NOOP("Stores the title of the subject of the file.\n"
-	    "Example: \"Symphony No.6, Op.68 'Pastoral'\"")));
+	_(kli18n("Name").untranslatedText()),
+	kli18n("Stores the title of the subject of the file.\n"
+	    "Example: \"Symphony No.6, Op.68 'Pastoral'\""));
     append(Kwave::INF_OPUS_FRAME_LEN,
 	FP_INTERNAL | FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Opus Frame Length")),
-	_(I18N_NOOP("Opus Frame Length in ms (supported values are "
-	            "2.5, 5, 10, 20, 40, or 60 ms)")));
+	_(kli18n("Opus Frame Length").untranslatedText()),
+	kli18n("Opus Frame Length in ms (supported values are "
+	            "2.5, 5, 10, 20, 40, or 60 ms)"));
     append(Kwave::INF_ORGANIZATION,
 	FP_NONE,
-	_(I18N_NOOP("Organization")),
-	_(I18N_NOOP("Name of the organization producing the track\n"
-	    "(i.e. the 'record label')")));
+	_(kli18n("Organization").untranslatedText()),
+	kli18n("Name of the organization producing the track\n"
+	    "(i.e. the 'record label')"));
     append(Kwave::INF_ORIGINAL,
 	FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Original")),
-	_(I18N_NOOP("Indicates whether the file is an original or a copy")));
+	_(kli18n("Original").untranslatedText()),
+	kli18n("Indicates whether the file is an original or a copy"));
     append(Kwave::INF_PERFORMER,
 	FP_NONE,
-	_(I18N_NOOP("Performer")),
-	_(I18N_NOOP("The artist(s) who performed the work. In classical\n"
+	_(kli18n("Performer").untranslatedText()),
+	kli18n("The artist(s) who performed the work. In classical\n"
 	    "music this would be the conductor, orchestra, soloists.\n"
-	    "In an audio book it would be the actor who did the reading.")));
+	    "In an audio book it would be the actor who did the reading."));
     append(Kwave::INF_PRIVATE,
 	FP_NONE,
-	_(I18N_NOOP("Private")),
-	_(I18N_NOOP("Indicates whether the subject is private")));
+	_(kli18n("Private").untranslatedText()),
+	kli18n("Indicates whether the subject is private"));
     append(Kwave::INF_PRODUCT,
 	FP_NONE,
-	_(I18N_NOOP("Product")),
-	_(I18N_NOOP("Specifies the name or the title the\n"
+	_(kli18n("Product").untranslatedText()),
+	kli18n("Specifies the name or the title the\n"
 	    "file was originally intended for.\n"
-	    "Example: 'Linux audio collection'")));
+	    "Example: 'Linux audio collection'"));
     append(Kwave::INF_SAMPLE_FORMAT,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Sample Format")),
-	_(I18N_NOOP("Format used for storing the digitized audio samples.\n"
-	    "Example: '32-bit IEEE floating-point'")));
+	_(kli18n("Sample Format").untranslatedText()),
+	kli18n("Format used for storing the digitized audio samples.\n"
+	    "Example: '32-bit IEEE floating-point'"));
     append(Kwave::INF_SAMPLE_RATE,
 	FP_INTERNAL | FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Sample Rate")),
-	_(I18N_NOOP("Number of samples per second")));
+	_(kli18n("Sample Rate").untranslatedText()),
+	kli18n("Number of samples per second"));
     append(Kwave::INF_SOFTWARE,
 	FP_NONE,
-	_(I18N_NOOP("Software")),
-	_(I18N_NOOP("Identifies the name of the software package\n"
+	_(kli18n("Software").untranslatedText()),
+	kli18n("Identifies the name of the software package\n"
 	    "used to create the file.\n"
-	    "Example: 'Kwave v0.6.4-1'")));
+	    "Example: 'Kwave v0.6.4-1'"));
     append(Kwave::INF_SOURCE,
 	FP_NONE,
-	_(I18N_NOOP("Source")),
-	_(I18N_NOOP("Identifies the name of the person or organization\n"
+	_(kli18n("Source").untranslatedText()),
+	kli18n("Identifies the name of the person or organization\n"
 	    "who supplied the original subject of the file.\n"
-	    "Example: 'Chaotic Sound Research'")));
+	    "Example: 'Chaotic Sound Research'"));
     append(Kwave::INF_SOURCE_FORM,
 	FP_NONE,
-	_(I18N_NOOP("Source form")),
-	_(I18N_NOOP("Identifies the original form of\n"
+	_(kli18n("Source form").untranslatedText()),
+	kli18n("Identifies the original form of\n"
 	    "the material that was digitized.\n"
 	    "Examples: 'Record/Vinyl/90RPM', 'Audio DAT', "
-	    "'tape/CrO2/60min'")));
+	    "'tape/CrO2/60min'"));
     append(Kwave::INF_SUBJECT,
 	FP_NONE,
-	_(I18N_NOOP("Subject")),
-	_(I18N_NOOP("Describes the subject of the file.\n"
-	    "Example: 'Bird voices at early morning'")));
+	_(kli18n("Subject").untranslatedText()),
+	kli18n("Describes the subject of the file.\n"
+	    "Example: 'Bird voices at early morning'"));
     append(Kwave::INF_TECHNICAN,
 	FP_NONE,
-	_(I18N_NOOP("Technician")),
-	_(I18N_NOOP(
+	_(kli18n("Technician").untranslatedText()),
+	kli18n(
 	    "Identifies the technician who digitized the subject file.\n"
-	    "Example: 'Torvalds, Linus'")));
+	    "Example: 'Torvalds, Linus'"));
     append(Kwave::INF_TRACK,
 	FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Track")),
-	_(I18N_NOOP("Track of the CD if the source was a CDROM.")));
+	_(kli18n("Track").untranslatedText()),
+	kli18n("Track of the CD if the source was a CDROM."));
     append(Kwave::INF_TRACKS,
 	FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Tracks")),
-	_(I18N_NOOP("Number of tracks of the CD if the source was a CDROM.")));
+	_(kli18n("Tracks").untranslatedText()),
+	kli18n("Number of tracks of the CD if the source was a CDROM."));
     append(Kwave::INF_CHANNELS,
 	FP_INTERNAL | FP_NO_LOAD_SAVE | FP_FORMAT_NUMERIC,
-	_(I18N_NOOP("Channels")),
-	_(I18N_NOOP("Specifies the number of channels of the signal.")));
+	_(kli18n("Channels").untranslatedText()),
+	kli18n("Specifies the number of channels of the signal."));
     append(Kwave::INF_VBR_QUALITY,
 	FP_INTERNAL | FP_NO_LOAD_SAVE,
-	_(I18N_NOOP("Base Quality")),
-	_(I18N_NOOP("Base quality of the compression in VBR mode")));
+	_(kli18n("Base Quality").untranslatedText()),
+	kli18n("Base quality of the compression in VBR mode"));
     append(Kwave::INF_VERSION,
 	FP_NONE,
-	_(I18N_NOOP("Version")),
-	_(I18N_NOOP("May be used to differentiate multiple versions\n"
+	_(kli18n("Version").untranslatedText()),
+	kli18n("May be used to differentiate multiple versions\n"
 	    "of the same track title in a single collection.\n"
-	    "(e.g. remix info)")));
+	    "(e.g. remix info)"));
 
     // please do not simply extend here, sort in alphabetically instead...
 
